summaryrefslogtreecommitdiffstats
path: root/src/blueshift_randr_c.h
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-04-05 19:51:20 +0200
committerMattias Andrée <maandree@operamail.com>2014-04-05 19:51:20 +0200
commit3b54aa6b6b0baa8d30ddd6290ad43ef42e745968 (patch)
treeafc40a5244a2023fb531b2cebb2d7d4f6d48c534 /src/blueshift_randr_c.h
parentremove crtc parameter from C and Cython functions for VidMode (diff)
downloadblueshift-3b54aa6b6b0baa8d30ddd6290ad43ef42e745968.tar.gz
blueshift-3b54aa6b6b0baa8d30ddd6290ad43ef42e745968.tar.bz2
blueshift-3b54aa6b6b0baa8d30ddd6290ad43ef42e745968.tar.xz
support more than 64 monitors with randr
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to 'src/blueshift_randr_c.h')
-rw-r--r--src/blueshift_randr_c.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/blueshift_randr_c.h b/src/blueshift_randr_c.h
index db12770..8ab21f3 100644
--- a/src/blueshift_randr_c.h
+++ b/src/blueshift_randr_c.h
@@ -81,13 +81,13 @@ uint16_t* blueshift_randr_read(int use_crtc);
/**
* Apply stage of colour curve control
*
* @param use_crtcs Mask of CRTC:s to use
* @param r_curve The red colour curve
* @param g_curve The green colour curve
* @param b_curve The blue colour curve
* @return Zero on success
*/
-int blueshift_randr_apply(uint64_t use_crtcs, uint16_t* r_curve, uint16_t* g_curve, uint16_t* b_curve);
+int blueshift_randr_apply(int use_crtc, uint16_t* r_curve, uint16_t* g_curve, uint16_t* b_curve);
/**
* Resource freeing stage of colour curve control
@@ -81,13 +81,13 @@ uint16_t* blueshift_randr_read(int use_crtc);
* Apply stage of colour curve control
*
- * @param use_crtcs Mask of CRTC:s to use
- * @param r_curve The red colour curve
- * @param g_curve The green colour curve
- * @param b_curve The blue colour curve
- * @return Zero on success
+ * @param use_crtc The CRTC to use, -1 for all
+ * @param r_curve The red colour curve
+ * @param g_curve The green colour curve
+ * @param b_curve The blue colour curve
+ * @return Zero on success
*/